#ifndef NT2_INCLUDE_FUNCTIONS_POLYVAL_HPP_INCLUDED
#define NT2_INCLUDE_FUNCTIONS_POLYVAL_HPP_INCLUDED

#include <nt2/polynom/include/functions/polyval.hpp>

#endif
